==> albert_0.27.0.orig.tar.gz: albert-0.27.0/plugins/applications/i18n/applications_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ApplicationBase</name>
    <message>
        <source>Launch application</source>
        <translation>Anwendung starten</translation>
    </message>
</context>
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Run desktop applications as described in the [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/).</source>
        <translation>Führen Sie Desktop-Anwendungen gemäß der [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/) aus.</translation>
    </message>
    <message>
        <source>Ignore &apos;OnlyShowIn&apos;/&apos;NotShowIn&apos;</source>
        <translation>&apos;OnlyShowIn&apos;/&apos;NotShowIn&apos; ignorieren</translation>
    </message>
    <message>
        <source>Use &apos;Exec&apos;</source>
        <translation>&apos;Exec&apos; verwenden</translation>
    </message>
    <message>
        <source>Use &apos;Keywords&apos;</source>
        <translation>&apos;Keywords&apos; verwenden</translation>
    </message>
    <message>
        <source>Use &apos;GenericName&apos;</source>
        <translation>&apos;GenericName&apos; verwenden</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Open desktop entry</source>
        <translation>Desktop Entry öffnen</translation>
    </message>
</context>
<context>
    <name>PluginBase</name>
    <message>
        <source>Report missing terminals &lt;a href=&quot;%1&quot;&gt;here&lt;/a&gt;.</source>
        <translation>Fehlend Terminals &lt;a href=&quot;%1&quot;&gt;melden&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>No terminal available.</source>
        <translation>Kein Terminal verfügbar.</translation>
    </message>
    <message>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <source>Split CamelCase words (medial capital)</source>
        <translation>CamelCase trennen (Binnenmajuskel)</translation>
    </message>
    <message>
        <source>Use acronyms</source>
        <translation>Akronyme verwenden</translation>
    </message>
    <message>
        <source>Use non-localized name</source>
        <translation>Nicht lokalisierten Namen verwenden</translation>
    </message>
</context>
<context>
    <name>Terminal</name>
    <message>
        <source>Failed to run terminal with script: getpwuid(…) failed.</source>
        <translation>Fehler beim Ausführen des Terminals mit Skript: getpwuid(…) fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Failed to run terminal with script: Script is empty.</source>
        <translation>Fehler beim Ausführen des Terminals mit Skript: Skript ist leer.</translation>
    </message>
    <message>
        <source>Failed to run terminal with script: Could not create temporary script file.</source>
        <translation>Fehler beim Ausführen des Terminals mit Skript: Temporäre Skriptdatei konnte nicht erstellt werden.</translation>
    </message>
</context>
</TS>

==> albert_0.27.8.orig.tar.gz: albert-0.27.8/plugins/applications/i18n/applications_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ApplicationBase</name>
    <message>
        <source>Launch application</source>
        <translation>Anwendung starten</translation>
    </message>
</context>
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Run desktop applications as described in the [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/).</source>
        <translation>Führen Sie Desktop-Anwendungen gemäß der [freedesktop.org Desktop Entry Specification](https://specifications.freedesktop.org/desktop-entry-spec/latest/) aus.</translation>
    </message>
    <message>
        <source>Ignore &apos;OnlyShowIn&apos;/&apos;NotShowIn&apos;</source>
        <translation>&apos;OnlyShowIn&apos;/&apos;NotShowIn&apos; ignorieren</translation>
    </message>
    <message>
        <source>Use &apos;Exec&apos;</source>
        <translation>&apos;Exec&apos; verwenden</translation>
    </message>
    <message>
        <source>Use &apos;Keywords&apos;</source>
        <translation>&apos;Keywords&apos; verwenden</translation>
    </message>
    <message>
        <source>Use &apos;GenericName&apos;</source>
        <translation>&apos;GenericName&apos; verwenden</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Open desktop entry</source>
        <translation>Desktop Entry öffnen</translation>
    </message>
</context>
<context>
    <name>PluginBase</name>
    <message>
        <source>Report missing terminals &lt;a href=&quot;%1&quot;&gt;here&lt;/a&gt;.</source>
        <translation>Fehlende Terminals &lt;a href=&quot;%1&quot;&gt;melden&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>No terminal available.</source>
        <translation>Kein Terminal verfügbar.</translation>
    </message>
    <message>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <source>Split CamelCase words (medial capital)</source>
        <translation>CamelCase trennen (Binnenmajuskel)</translation>
    </message>
    <message>
        <source>Use acronyms</source>
        <translation>Akronyme verwenden</translation>
    </message>
    <message>
        <source>Use non-localized name</source>
        <translation>Nicht lokalisierten Namen verwenden</translation>
    </message>
</context>
<context>
    <name>Terminal</name>
    <message>
        <source>Failed to run terminal with script: getpwuid(…) failed.</source>
        <translation>Fehler beim Ausführen des Terminals mit Skript: getpwuid(…) fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Failed to run terminal with script: Script is empty.</source>
        <translation>Fehler beim Ausführen des Terminals mit Skript: Skript ist leer.</translation>
    </message>
    <message>
        <source>Failed to run terminal with script: Could not create temporary script file.</source>
        <translation>Fehler beim Ausführen des Terminals mit Skript: Temporäre Skriptdatei konnte nicht erstellt werden.</translation>
    </message>
</context>
</TS>
